@@ -6,15 +6,15 @@ from homematicip.aio.device import (
     AsyncWeatherSensorPlus,
     AsyncWeatherSensorPro,
 )
-from homematicip.aio.home import AsyncHome
 from homematicip.base.enums import WeatherCondition
 
 from homeassistant.components.weather import WeatherEntity
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import TEMP_CELSIUS
-from homeassistant.core import HomeAssistant
+from homeassistant.helpers.typing import HomeAssistantType
 
 from . import DOMAIN as HMIPC_DOMAIN, HMIPC_HAPID, HomematicipGenericDevice
+from .hap import HomematicipHAP
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -43,18 +43,18 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
 
 
 async def async_setup_entry(
-    hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities
+    hass: HomeAssistantType, config_entry: ConfigEntry, async_add_entities
 ) -> None:
     """Set up the HomematicIP weather sensor from a config entry."""
-    home = hass.data[HMIPC_DOMAIN][config_entry.data[HMIPC_HAPID]].home
+    hap = hass.data[HMIPC_DOMAIN][config_entry.data[HMIPC_HAPID]]
     devices = []
-    for device in home.devices:
+    for device in hap.home.devices:
         if isinstance(device, AsyncWeatherSensorPro):
-            devices.append(HomematicipWeatherSensorPro(home, device))
+            devices.append(HomematicipWeatherSensorPro(hap, device))
         elif isinstance(device, (AsyncWeatherSensor, AsyncWeatherSensorPlus)):
-            devices.append(HomematicipWeatherSensor(home, device))
+            devices.append(HomematicipWeatherSensor(hap, device))
 
-    devices.append(HomematicipHomeWeather(home))
+    devices.append(HomematicipHomeWeather(hap))
 
     if devices:
         async_add_entities(devices)
@@ -63,9 +63,9 @@ async def async_setup_entry(
 class HomematicipWeatherSensor(HomematicipGenericDevice, WeatherEntity):
     """representation of a HomematicIP Cloud weather sensor plus & basic."""
 
-    def __init__(self, home: AsyncHome, device) -> None:
+    def __init__(self, hap: HomematicipHAP, device) -> None:
         """Initialize the weather sensor."""
-        super().__init__(home, device)
+        super().__init__(hap, device)
 
     @property
     def name(self) -> str:
@@ -121,10 +121,10 @@ class HomematicipWeatherSensorPro(HomematicipWeatherSensor):
 class HomematicipHomeWeather(HomematicipGenericDevice, WeatherEntity):
     """representation of a HomematicIP Cloud home weather."""
 
-    def __init__(self, home: AsyncHome) -> None:
+    def __init__(self, hap: HomematicipHAP) -> None:
         """Initialize the home weather."""
-        home.weather.modelType = "HmIP-Home-Weather"
-        super().__init__(home, home)
+        hap.home.modelType = "HmIP-Home-Weather"
+        super().__init__(hap, hap.home)
 
     @property
     def available(self) -> bool:
