@@ -9,8 +9,14 @@ import voluptuous as vol
 from homeassistant.components import mqtt, sensor
 from homeassistant.components.sensor import DEVICE_CLASSES_SCHEMA
 from homeassistant.const import (
-    CONF_DEVICE, CONF_DEVICE_CLASS, CONF_FORCE_UPDATE, CONF_ICON, CONF_NAME,
-    CONF_UNIT_OF_MEASUREMENT, CONF_VALUE_TEMPLATE)
+    CONF_DEVICE,
+    CONF_DEVICE_CLASS,
+    CONF_FORCE_UPDATE,
+    CONF_ICON,
+    CONF_NAME,
+    CONF_UNIT_OF_MEASUREMENT,
+    CONF_VALUE_TEMPLATE,
+)
 from homeassistant.core import callback
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -20,65 +26,82 @@ from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 from homeassistant.util import dt as dt_util
 
 from . import (
-    ATTR_DISCOVERY_HASH, CONF_QOS, CONF_STATE_TOPIC, CONF_UNIQUE_ID,
-    MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
-    MqttEntityDeviceInfo, subscription)
+    ATTR_DISCOVERY_HASH,
+    CONF_QOS,
+    CONF_STATE_TOPIC,
+    CONF_UNIQUE_ID,
+    MqttAttributes,
+    MqttAvailability,
+    MqttDiscoveryUpdate,
+    MqttEntityDeviceInfo,
+    subscription,
+)
 from .discovery import MQTT_DISCOVERY_NEW, clear_discovery_hash
 
 _LOGGER = logging.getLogger(__name__)
 
-CONF_EXPIRE_AFTER = 'expire_after'
-CONF_JSON_ATTRS = 'json_attributes'
+CONF_EXPIRE_AFTER = "expire_after"
+CONF_JSON_ATTRS = "json_attributes"
 
-DEFAULT_NAME = 'MQTT Sensor'
+DEFAULT_NAME = "MQTT Sensor"
 DEFAULT_FORCE_UPDATE = False
-PLATFORM_SCHEMA = mqtt.MQTT_RO_PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_DEVICE): mqtt.MQTT_ENTITY_DEVICE_INFO_SCHEMA,
-    vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
-    vol.Optional(CONF_EXPIRE_AFTER): cv.positive_int,
-    vol.Optional(CONF_FORCE_UPDATE, default=DEFAULT_FORCE_UPDATE): cv.boolean,
-    vol.Optional(CONF_ICON): cv.icon,
-    vol.Optional(CONF_JSON_ATTRS, default=[]): cv.ensure_list_csv,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_UNIQUE_ID): cv.string,
-    vol.Optional(CONF_UNIT_OF_MEASUREMENT): cv.string,
-}).extend(mqtt.MQTT_AVAILABILITY_SCHEMA.schema).extend(
-    mqtt.MQTT_JSON_ATTRS_SCHEMA.schema)
+PLATFORM_SCHEMA = (
+    mqtt.MQTT_RO_PLATFORM_SCHEMA.extend(
+        {
+            vol.Optional(CONF_DEVICE): mqtt.MQTT_ENTITY_DEVICE_INFO_SCHEMA,
+            vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
+            vol.Optional(CONF_EXPIRE_AFTER): cv.positive_int,
+            vol.Optional(CONF_FORCE_UPDATE, default=DEFAULT_FORCE_UPDATE): cv.boolean,
+            vol.Optional(CONF_ICON): cv.icon,
+            vol.Optional(CONF_JSON_ATTRS, default=[]): cv.ensure_list_csv,
+            vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+            vol.Optional(CONF_UNIQUE_ID): cv.string,
+            vol.Optional(CONF_UNIT_OF_MEASUREMENT): cv.string,
+        }
+    )
+    .extend(mqtt.MQTT_AVAILABILITY_SCHEMA.schema)
+    .extend(mqtt.MQTT_JSON_ATTRS_SCHEMA.schema)
+)
 
 
-async def async_setup_platform(hass: HomeAssistantType, config: ConfigType,
-                               async_add_entities, discovery_info=None):
+async def async_setup_platform(
+    hass: HomeAssistantType, config: ConfigType, async_add_entities, discovery_info=None
+):
     """Set up MQTT sensors through configuration.yaml."""
     await _async_setup_entity(config, async_add_entities)
 
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up MQTT sensors dynamically through MQTT discovery."""
+
     async def async_discover_sensor(discovery_payload):
         """Discover and add a discovered MQTT sensor."""
         try:
             discovery_hash = discovery_payload.pop(ATTR_DISCOVERY_HASH)
             config = PLATFORM_SCHEMA(discovery_payload)
-            await _async_setup_entity(config, async_add_entities, config_entry,
-                                      discovery_hash)
+            await _async_setup_entity(
+                config, async_add_entities, config_entry, discovery_hash
+            )
         except Exception:
             if discovery_hash:
                 clear_discovery_hash(hass, discovery_hash)
             raise
 
-    async_dispatcher_connect(hass,
-                             MQTT_DISCOVERY_NEW.format(sensor.DOMAIN, 'mqtt'),
-                             async_discover_sensor)
+    async_dispatcher_connect(
+        hass, MQTT_DISCOVERY_NEW.format(sensor.DOMAIN, "mqtt"), async_discover_sensor
+    )
 
 
-async def _async_setup_entity(config: ConfigType, async_add_entities,
-                              config_entry=None, discovery_hash=None):
+async def _async_setup_entity(
+    config: ConfigType, async_add_entities, config_entry=None, discovery_hash=None
+):
     """Set up MQTT sensor."""
     async_add_entities([MqttSensor(config, config_entry, discovery_hash)])
 
 
-class MqttSensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
-                 MqttEntityDeviceInfo, Entity):
+class MqttSensor(
+    MqttAttributes, MqttAvailability, MqttDiscoveryUpdate, MqttEntityDeviceInfo, Entity
+):
     """Representation of a sensor that can be updated using MQTT."""
 
     def __init__(self, config, config_entry, discovery_hash):
@@ -93,13 +116,14 @@ class MqttSensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
         device_config = config.get(CONF_DEVICE)
 
         if config.get(CONF_JSON_ATTRS):
-            _LOGGER.warning('configuration variable "json_attributes" is '
-                            'deprecated, replace with "json_attributes_topic"')
+            _LOGGER.warning(
+                'configuration variable "json_attributes" is '
+                'deprecated, replace with "json_attributes_topic"'
+            )
 
         MqttAttributes.__init__(self, config)
         MqttAvailability.__init__(self, config)
-        MqttDiscoveryUpdate.__init__(self, discovery_hash,
-                                     self.discovery_update)
+        MqttDiscoveryUpdate.__init__(self, discovery_hash, self.discovery_update)
         MqttEntityDeviceInfo.__init__(self, device_config, config_entry)
 
     async def async_added_to_hass(self):
@@ -136,11 +160,11 @@ class MqttSensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
                     self._expiration_trigger = None
 
                 # Set new trigger
-                expiration_at = (
-                    dt_util.utcnow() + timedelta(seconds=expire_after))
+                expiration_at = dt_util.utcnow() + timedelta(seconds=expire_after)
 
                 self._expiration_trigger = async_track_point_in_utc_time(
-                    self.hass, self.value_is_expired, expiration_at)
+                    self.hass, self.value_is_expired, expiration_at
+                )
 
             json_attributes = set(self._config[CONF_JSON_ATTRS])
             if json_attributes:
@@ -148,8 +172,9 @@ class MqttSensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
                 try:
                     json_dict = json.loads(payload)
                     if isinstance(json_dict, dict):
-                        attrs = {k: json_dict[k] for k in
-                                 json_attributes & json_dict.keys()}
+                        attrs = {
+                            k: json_dict[k] for k in json_attributes & json_dict.keys()
+                        }
                         self._attributes = attrs
                     else:
                         _LOGGER.warning("JSON result was not a dictionary")
@@ -159,20 +184,28 @@ class MqttSensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
 
             if template is not None:
                 payload = template.async_render_with_possible_json_value(
-                    payload, self._state)
+                    payload, self._state
+                )
             self._state = payload
             self.async_write_ha_state()
 
         self._sub_state = await subscription.async_subscribe_topics(
-            self.hass, self._sub_state,
-            {'state_topic': {'topic': self._config[CONF_STATE_TOPIC],
-                             'msg_callback': message_received,
-                             'qos': self._config[CONF_QOS]}})
+            self.hass,
+            self._sub_state,
+            {
+                "state_topic": {
+                    "topic": self._config[CONF_STATE_TOPIC],
+                    "msg_callback": message_received,
+                    "qos": self._config[CONF_QOS],
+                }
+            },
+        )
 
     async def async_will_remove_from_hass(self):
         """Unsubscribe when removed."""
         self._sub_state = await subscription.async_unsubscribe_topics(
-            self.hass, self._sub_state)
+            self.hass, self._sub_state
+        )
         await MqttAttributes.async_will_remove_from_hass(self)
         await MqttAvailability.async_will_remove_from_hass(self)
 
