@@ -3,6 +3,7 @@ import asyncio
 import logging
 
 import plexapi.exceptions
+from plexwebsocket import PlexWebsocket
 import requests.exceptions
 import voluptuous as vol
 
@@ -15,8 +16,14 @@ from homeassistant.const import (
     CONF_TOKEN,
     CONF_URL,
     CONF_VERIFY_SSL,
+    EVENT_HOMEASSISTANT_STOP,
 )
 from homeassistant.helpers import config_validation as cv
+from homeassistant.helpers.aiohttp_client import async_get_clientsession
+from homeassistant.helpers.dispatcher import (
+    async_dispatcher_connect,
+    async_dispatcher_send,
+)
 
 from .const import (
     CONF_USE_EPISODE_ART,
@@ -26,12 +33,14 @@ from .const import (
     DEFAULT_PORT,
     DEFAULT_SSL,
     DEFAULT_VERIFY_SSL,
+    DISPATCHERS,
     DOMAIN as PLEX_DOMAIN,
     PLATFORMS,
     PLEX_MEDIA_PLAYER_OPTIONS,
     PLEX_SERVER_CONFIG,
-    REFRESH_LISTENERS,
+    PLEX_UPDATE_PLATFORMS_SIGNAL,
     SERVERS,
+    WEBSOCKETS,
 )
 from .server import PlexServer
 
@@ -64,7 +73,7 @@ _LOGGER = logging.getLogger(__package__)
 
 def setup(hass, config):
     """Set up the Plex component."""
-    hass.data.setdefault(PLEX_DOMAIN, {SERVERS: {}, REFRESH_LISTENERS: {}})
+    hass.data.setdefault(PLEX_DOMAIN, {SERVERS: {}, DISPATCHERS: {}, WEBSOCKETS: {}})
 
     plex_config = config.get(PLEX_DOMAIN, {})
     if plex_config:
@@ -104,7 +113,7 @@ async def async_setup_entry(hass, entry):
         )
         hass.config_entries.async_update_entry(entry, options=options)
 
-    plex_server = PlexServer(server_config, entry.options)
+    plex_server = PlexServer(hass, server_config, entry.options)
     try:
         await hass.async_add_executor_job(plex_server.connect)
     except requests.exceptions.ConnectionError as error:
@@ -129,7 +138,8 @@ async def async_setup_entry(hass, entry):
     _LOGGER.debug(
         "Connected to: %s (%s)", plex_server.friendly_name, plex_server.url_in_use
     )
-    hass.data[PLEX_DOMAIN][SERVERS][plex_server.machine_identifier] = plex_server
+    server_id = plex_server.machine_identifier
+    hass.data[PLEX_DOMAIN][SERVERS][server_id] = plex_server
 
     for platform in PLATFORMS:
         hass.async_create_task(
@@ -138,6 +148,30 @@ async def async_setup_entry(hass, entry):
 
     entry.add_update_listener(async_options_updated)
 
+    unsub = async_dispatcher_connect(
+        hass,
+        PLEX_UPDATE_PLATFORMS_SIGNAL.format(server_id),
+        plex_server.update_platforms,
+    )
+    hass.data[PLEX_DOMAIN][DISPATCHERS].setdefault(server_id, [])
+    hass.data[PLEX_DOMAIN][DISPATCHERS][server_id].append(unsub)
+
+    def update_plex():
+        async_dispatcher_send(hass, PLEX_UPDATE_PLATFORMS_SIGNAL.format(server_id))
+
+    session = async_get_clientsession(hass)
+    websocket = PlexWebsocket(plex_server.plex_server, update_plex, session)
+    hass.loop.create_task(websocket.listen())
+    hass.data[PLEX_DOMAIN][WEBSOCKETS][server_id] = websocket
+
+    def close_websocket_session(_):
+        websocket.close()
+
+    unsub = hass.bus.async_listen_once(
+        EVENT_HOMEASSISTANT_STOP, close_websocket_session
+    )
+    hass.data[PLEX_DOMAIN][DISPATCHERS][server_id].append(unsub)
+
     return True
 
 
@@ -145,8 +179,12 @@ async def async_unload_entry(hass, entry):
     """Unload a config entry."""
     server_id = entry.data[CONF_SERVER_IDENTIFIER]
 
-    cancel = hass.data[PLEX_DOMAIN][REFRESH_LISTENERS].pop(server_id)
-    await hass.async_add_executor_job(cancel)
+    websocket = hass.data[PLEX_DOMAIN][WEBSOCKETS].pop(server_id)
+    websocket.close()
+
+    dispatchers = hass.data[PLEX_DOMAIN][DISPATCHERS].pop(server_id)
+    for unsub in dispatchers:
+        unsub()
 
     tasks = [
         hass.config_entries.async_forward_entry_unload(entry, platform)
