@@ -19,11 +19,10 @@ from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.dispatcher import dispatcher_send
 from homeassistant.helpers.event import async_track_time_interval
+from homeassistant.util import slugify
 
 from .const import (
     ATTR_TORRENT,
-    DATA_TRANSMISSION,
-    DATA_UPDATED,
     DEFAULT_NAME,
     DEFAULT_PORT,
     DEFAULT_SCAN_INTERVAL,
@@ -37,74 +36,77 @@ _LOGGER = logging.getLogger(__name__)
 
 SERVICE_ADD_TORRENT_SCHEMA = vol.Schema({vol.Required(ATTR_TORRENT): cv.string})
 
+TRANS_SCHEMA = vol.All(
+    vol.Schema(
+        {
+            vol.Required(CONF_HOST): cv.string,
+            vol.Optional(CONF_PASSWORD): cv.string,
+            vol.Optional(CONF_USERNAME): cv.string,
+            vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+            vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+            vol.Optional(
+                CONF_SCAN_INTERVAL, default=DEFAULT_SCAN_INTERVAL
+            ): cv.time_period,
+        }
+    )
+)
+
 CONFIG_SCHEMA = vol.Schema(
-    {
-        DOMAIN: vol.Schema(
-            {
-                vol.Required(CONF_HOST): cv.string,
-                vol.Optional(CONF_PASSWORD): cv.string,
-                vol.Optional(CONF_USERNAME): cv.string,
-                vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
-                vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-                vol.Optional(
-                    CONF_SCAN_INTERVAL, default=DEFAULT_SCAN_INTERVAL
-                ): cv.time_period,
-            }
-        )
-    },
-    extra=vol.ALLOW_EXTRA,
+    {DOMAIN: vol.All(cv.ensure_list, [TRANS_SCHEMA])}, extra=vol.ALLOW_EXTRA
 )
 
 
 async def async_setup(hass, config):
     """Import the Transmission Component from config."""
-    if not hass.config_entries.async_entries(DOMAIN) and DOMAIN in config:
-        hass.async_create_task(
-            hass.config_entries.flow.async_init(
-                DOMAIN, context={"source": SOURCE_IMPORT}, data=config[DOMAIN]
+    if DOMAIN in config:
+        for entry in config[DOMAIN]:
+            hass.async_create_task(
+                hass.config_entries.flow.async_init(
+                    DOMAIN, context={"source": SOURCE_IMPORT}, data=entry
+                )
             )
-        )
 
     return True
 
 
 async def async_setup_entry(hass, config_entry):
     """Set up the Transmission Component."""
-    if DOMAIN not in hass.data:
-        hass.data[DOMAIN] = {}
-
-    if not config_entry.options:
-        await async_populate_options(hass, config_entry)
-
     client = TransmissionClient(hass, config_entry)
-    client_id = config_entry.entry_id
-    hass.data[DOMAIN][client_id] = client
+    hass.data.setdefault(DOMAIN, {})[config_entry.entry_id] = client
+
     if not await client.async_setup():
         return False
 
     return True
 
 
-async def async_unload_entry(hass, entry):
+async def async_unload_entry(hass, config_entry):
     """Unload Transmission Entry from config_entry."""
-    hass.services.async_remove(DOMAIN, SERVICE_ADD_TORRENT)
-    if hass.data[DOMAIN][entry.entry_id].unsub_timer:
-        hass.data[DOMAIN][entry.entry_id].unsub_timer()
+    client = hass.data[DOMAIN][config_entry.entry_id]
+    hass.services.async_remove(DOMAIN, client.service_name)
+    if client.unsub_timer:
+        client.unsub_timer()
 
     for component in "sensor", "switch":
-        await hass.config_entries.async_forward_entry_unload(entry, component)
+        await hass.config_entries.async_forward_entry_unload(config_entry, component)
 
-    del hass.data[DOMAIN]
+    hass.data[DOMAIN].pop(config_entry.entry_id)
 
     return True
 
 
-async def get_api(hass, host, port, username=None, password=None):
+async def get_api(hass, entry):
     """Get Transmission client."""
+    host = entry[CONF_HOST]
+    port = entry[CONF_PORT]
+    username = entry.get(CONF_USERNAME)
+    password = entry.get(CONF_PASSWORD)
+
     try:
         api = await hass.async_add_executor_job(
             transmissionrpc.Client, host, port, username, password
         )
+        _LOGGER.debug("Successfully connected to %s", host)
         return api
 
     except TransmissionError as error:
@@ -112,20 +114,13 @@ async def get_api(hass, host, port, username=None, password=None):
             _LOGGER.error("Credentials for Transmission client are not valid")
             raise AuthenticationError
         if "111: Connection refused" in str(error):
-            _LOGGER.error("Connecting to the Transmission client failed")
+            _LOGGER.error("Connecting to the Transmission client %s failed", host)
             raise CannotConnect
 
         _LOGGER.error(error)
         raise UnknownError
 
 
-async def async_populate_options(hass, config_entry):
-    """Populate default options for Transmission Client."""
-    options = {CONF_SCAN_INTERVAL: config_entry.data["options"][CONF_SCAN_INTERVAL]}
-
-    hass.config_entries.async_update_entry(config_entry, options=options)
-
-
 class TransmissionClient:
     """Transmission Client Object."""
 
@@ -133,33 +128,35 @@ class TransmissionClient:
         """Initialize the Transmission RPC API."""
         self.hass = hass
         self.config_entry = config_entry
-        self.scan_interval = self.config_entry.options[CONF_SCAN_INTERVAL]
-        self.tm_data = None
+        self._tm_data = None
         self.unsub_timer = None
 
+    @property
+    def service_name(self):
+        """Return the service name."""
+        return slugify(f"{SERVICE_ADD_TORRENT}_{self.config_entry.data[CONF_NAME]}")
+
+    @property
+    def api(self):
+        """Return the tm_data object."""
+        return self._tm_data
+
     async def async_setup(self):
         """Set up the Transmission client."""
 
-        config = {
-            CONF_HOST: self.config_entry.data[CONF_HOST],
-            CONF_PORT: self.config_entry.data[CONF_PORT],
-            CONF_USERNAME: self.config_entry.data.get(CONF_USERNAME),
-            CONF_PASSWORD: self.config_entry.data.get(CONF_PASSWORD),
-        }
         try:
-            api = await get_api(self.hass, **config)
+            api = await get_api(self.hass, self.config_entry.data)
         except CannotConnect:
             raise ConfigEntryNotReady
         except (AuthenticationError, UnknownError):
             return False
 
-        self.tm_data = self.hass.data[DOMAIN][DATA_TRANSMISSION] = TransmissionData(
-            self.hass, self.config_entry, api
-        )
+        self._tm_data = TransmissionData(self.hass, self.config_entry, api)
 
-        await self.hass.async_add_executor_job(self.tm_data.init_torrent_list)
-        await self.hass.async_add_executor_job(self.tm_data.update)
-        self.set_scan_interval(self.scan_interval)
+        await self.hass.async_add_executor_job(self._tm_data.init_torrent_list)
+        await self.hass.async_add_executor_job(self._tm_data.update)
+        self.add_options()
+        self.set_scan_interval(self.config_entry.options[CONF_SCAN_INTERVAL])
 
         for platform in ["sensor", "switch"]:
             self.hass.async_create_task(
@@ -181,19 +178,31 @@ class TransmissionClient:
                 )
 
         self.hass.services.async_register(
-            DOMAIN, SERVICE_ADD_TORRENT, add_torrent, schema=SERVICE_ADD_TORRENT_SCHEMA
+            DOMAIN, self.service_name, add_torrent, schema=SERVICE_ADD_TORRENT_SCHEMA
         )
 
         self.config_entry.add_update_listener(self.async_options_updated)
 
         return True
 
+    def add_options(self):
+        """Add options for entry."""
+        if not self.config_entry.options:
+            scan_interval = self.config_entry.data.pop(
+                CONF_SCAN_INTERVAL, DEFAULT_SCAN_INTERVAL
+            )
+            options = {CONF_SCAN_INTERVAL: scan_interval}
+
+            self.hass.config_entries.async_update_entry(
+                self.config_entry, options=options
+            )
+
     def set_scan_interval(self, scan_interval):
         """Update scan interval."""
 
-        def refresh(event_time):
+        async def refresh(event_time):
             """Get the latest data from Transmission."""
-            self.tm_data.update()
+            self._tm_data.update()
 
         if self.unsub_timer is not None:
             self.unsub_timer()
@@ -215,6 +224,7 @@ class TransmissionData:
     def __init__(self, hass, config, api):
         """Initialize the Transmission RPC API."""
         self.hass = hass
+        self.config = config
         self.data = None
         self.torrents = None
         self.session = None
@@ -223,6 +233,16 @@ class TransmissionData:
         self.completed_torrents = []
         self.started_torrents = []
 
+    @property
+    def host(self):
+        """Return the host name."""
+        return self.config.data[CONF_HOST]
+
+    @property
+    def signal_options_update(self):
+        """Option update signal per transmission entry."""
+        return f"tm-options-{self.host}"
+
     def update(self):
         """Get the latest data from Transmission instance."""
         try:
@@ -232,14 +252,13 @@ class TransmissionData:
 
             self.check_completed_torrent()
             self.check_started_torrent()
-            _LOGGER.debug("Torrent Data Updated")
+            _LOGGER.debug("Torrent Data for %s Updated", self.host)
 
             self.available = True
         except TransmissionError:
             self.available = False
-            _LOGGER.error("Unable to connect to Transmission client")
-
-        dispatcher_send(self.hass, DATA_UPDATED)
+            _LOGGER.error("Unable to connect to Transmission client %s", self.host)
+        dispatcher_send(self.hass, self.signal_options_update)
 
     def init_torrent_list(self):
         """Initialize torrent lists."""
