@@ -8,8 +8,7 @@ from . import DATA_KEY, VolvoEntity
 _LOGGER = logging.getLogger(__name__)
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up a Volvo switch."""
     if discovery_info is None:
         return
