@@ -6,13 +6,14 @@ import os
 from typing import Dict, List, Optional, Callable, Union, Any, Type
 
 from homeassistant.const import EVENT_HOMEASSISTANT_STOP
-from homeassistant.core import HomeAssistant, callback
+from homeassistant.core import HomeAssistant, callback, CALLBACK_TYPE
 from homeassistant.loader import bind_hass
 from homeassistant.util import json as json_util
 from homeassistant.helpers.event import async_call_later
 
 
 # mypy: allow-untyped-calls, allow-untyped-defs, no-warn-return-any
+# mypy: no-check-untyped-defs
 
 STORAGE_DIR = ".storage"
 _LOGGER = logging.getLogger(__name__)
@@ -71,8 +72,8 @@ class Store:
         self.hass = hass
         self._private = private
         self._data: Optional[Dict[str, Any]] = None
-        self._unsub_delay_listener = None
-        self._unsub_stop_listener = None
+        self._unsub_delay_listener: Optional[CALLBACK_TYPE] = None
+        self._unsub_stop_listener: Optional[CALLBACK_TYPE] = None
         self._write_lock = asyncio.Lock()
         self._load_task: Optional[asyncio.Future] = None
         self._encoder = encoder
@@ -136,9 +137,7 @@ class Store:
         await self._async_handle_write_data()
 
     @callback
-    def async_delay_save(
-        self, data_func: Callable[[], Dict], delay: Optional[int] = None
-    ) -> None:
+    def async_delay_save(self, data_func: Callable[[], Dict], delay: float = 0) -> None:
         """Save data with an optional delay."""
         self._data = {"version": self.version, "key": self.key, "data_func": data_func}
 
